==> zio-aws-docdb_2.13-5.17.146.1-sources.jar: zio/aws/docdb/model/CreateDbClusterSnapshotRequest.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateDbClusterSnapshotRequest(
    dbClusterSnapshotIdentifier: String,
    dbClusterIdentifier: String,
    tags: Option[Iterable[zio.aws.docdb.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest = {
    import CreateDbClusterSnapshotRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
      .builder()
      .dbClusterSnapshotIdentifier(
        dbClusterSnapshotIdentifier: java.lang.String
      )
      .dbClusterIdentifier(dbClusterIdentifier: java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.CreateDbClusterSnapshotRequest.ReadOnly =
    zio.aws.docdb.model.CreateDbClusterSnapshotRequest.wrap(buildAwsValue())
}
object CreateDbClusterSnapshotRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.CreateDbClusterSnapshotRequest =
      zio.aws.docdb.model.CreateDbClusterSnapshotRequest(
        dbClusterSnapshotIdentifier,
        dbClusterIdentifier,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def dbClusterSnapshotIdentifier: String
    def dbClusterIdentifier: String
    def tags: Option[List[zio.aws.docdb.model.Tag.ReadOnly]]
    def getDbClusterSnapshotIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbClusterSnapshotIdentifier)
    def getDbClusterIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbClusterIdentifier)
    def getTags: ZIO[Any, AwsError, List[zio.aws.docdb.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
  ) extends zio.aws.docdb.model.CreateDbClusterSnapshotRequest.ReadOnly {
    override val dbClusterSnapshotIdentifier: String =
      impl.dbClusterSnapshotIdentifier(): String
    override val dbClusterIdentifier: String =
      impl.dbClusterIdentifier(): String
    override val tags: Option[List[zio.aws.docdb.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
  ): zio.aws.docdb.model.CreateDbClusterSnapshotRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-docdb_2.13-6.20.78.3-sources.jar: zio/aws/docdb/model/CreateDbClusterSnapshotRequest.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateDbClusterSnapshotRequest(
    dbClusterSnapshotIdentifier: String,
    dbClusterIdentifier: String,
    tags: Optional[Iterable[zio.aws.docdb.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest = {
    import CreateDbClusterSnapshotRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
      .builder()
      .dbClusterSnapshotIdentifier(
        dbClusterSnapshotIdentifier: java.lang.String
      )
      .dbClusterIdentifier(dbClusterIdentifier: java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.CreateDbClusterSnapshotRequest.ReadOnly =
    zio.aws.docdb.model.CreateDbClusterSnapshotRequest.wrap(buildAwsValue())
}
object CreateDbClusterSnapshotRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.CreateDbClusterSnapshotRequest =
      zio.aws.docdb.model.CreateDbClusterSnapshotRequest(
        dbClusterSnapshotIdentifier,
        dbClusterIdentifier,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def dbClusterSnapshotIdentifier: String
    def dbClusterIdentifier: String
    def tags: Optional[List[zio.aws.docdb.model.Tag.ReadOnly]]
    def getDbClusterSnapshotIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbClusterSnapshotIdentifier)
    def getDbClusterIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbClusterIdentifier)
    def getTags: ZIO[Any, AwsError, List[zio.aws.docdb.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
  ) extends zio.aws.docdb.model.CreateDbClusterSnapshotRequest.ReadOnly {
    override val dbClusterSnapshotIdentifier: String =
      impl.dbClusterSnapshotIdentifier(): String
    override val dbClusterIdentifier: String =
      impl.dbClusterIdentifier(): String
    override val tags: Optional[List[zio.aws.docdb.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.CreateDbClusterSnapshotRequest
  ): zio.aws.docdb.model.CreateDbClusterSnapshotRequest.ReadOnly = new Wrapper(
    impl
  )
}
